===============
django-aws-xray
===============


Status
======
.. image:: https://travis-ci.org/mvantellingen/django-aws-xray.svg?branch=master
    :target: https://travis-ci.org/mvantellingen/django-aws-xray

.. image:: http://codecov.io/github/mvantellingen/django-aws-xray/coverage.svg?branch=master
    :target: http://codecov.io/github/mvantellingen/django-aws-xray?branch=master

.. image:: https://img.shields.io/pypi/v/django-aws-xray.svg
    :target: https://pypi.python.org/pypi/django-aws-xray/


Installation
============

.. code-block:: shell

   pip install django-aws-xray
